/**
 *
 * GPS Adapted From Adafruit_FONA lib:
 * Copyright: 2015 Adafruit
 * Author: Todd Treece
 * Licence: MIT
 * Adapted by http://iot.org.il
 **/
 
#include "Adafruit_FONA.h" //lib for the sim808 shield
#include <string.h>
#include <SoftwareSerial.h> //for communicating with sim808

#define FONA_RX 8
#define FONA_TX 7
#define FONA_RST 4

SoftwareSerial fonaSS = SoftwareSerial(FONA_TX, FONA_RX);
SoftwareSerial *fonaSerial = &fonaSS;

Adafruit_FONA fona = Adafruit_FONA(FONA_RST);

int Powerkey = 9;//pin for powering the SIM808
boolean gprson = false;
boolean gpson = false;
void power(void)
{
 //digitalWrite(Powerkey, LOW); 
 //delay(1000); // wait for 1 second
 digitalWrite(Powerkey, HIGH);
}
void flushSerial() {
 while (Serial.available())
 Serial.read();
}
void setup() {
 
 pinMode(Powerkey, OUTPUT); // initialize the digital pin as an output. 
 power(); //power on the sim808 or power down the sim808
 while (! Serial);
 Serial.begin(115200);
 Serial.println(F("Initializing sim808... (May take a few seconds)"));

 fonaSerial->begin(4800);
 if (! fona.begin(*fonaSerial)) {
 Serial.println(F("Couldn't find sim808"));
 while(1);
 }
 Serial.println(F("sim808 is OK")); 
 while(!gpson){
 delay(1000);
 Serial.println(F("Enabling GPS..."));
 if (!fona.enableGPS(true))
 Serial.println(F("GPS OK..."));
 gpson = true;
 }
 while(!gpson){
 delay(1000);
 fona.enableGPRS(false);
 Serial.println(F("Enabling GPRS"));
 if (!fona.enableGPRS(true))
 Serial.println(F("Failed to turn GPRS on"));
 else
 gprson = true;
 }
}

void loop() {
 delay(4000);
 if(!gprson){
 fona.enableGPRS(false);
 Serial.println(F("Enabling GPRS"));
 if (!fona.enableGPRS(true))
 Serial.println(F("Failed to turn GPRS on"));
 else
 gprson = true;
 }
 float latitude, longitude;
 boolean gps_success = fona.getGPS(&latitude, &longitude);
 if (gps_success)
 {
 Serial.print("GPS lat:");
 Serial.println(latitude, 6);
 Serial.print("GPS long:");
 Serial.println(longitude, 6);
 uint16_t statuscode;
 int16_t length;
 char url[100]="http://yourdomain.com/report.php?latitude=";
 char lati[10];
 dtostrf(latitude,1,6,lati);
 Serial.println(lati);
 char longi[10];
 dtostrf(longitude,1,6,longi);
 strcat(url, lati);
 strcat(url, "&");
 strcat(url, "longitude=");
 strcat(url, longi);
 flushSerial();
 Serial.println(url);
 if (!fona.HTTP_GET_start(url,&statuscode, (uint16_t *)&length))
 {
 Serial.println("Failed!");
 }
 while (length > 0) 
 {
 while (fona.available()) 
 {
 char c = fona.read();
 #if defined(__AVR_ATmega328P__) || defined(__AVR_ATmega168__)
 loop_until_bit_is_set(UCSR0A, UDRE0); // Wait until data register empty. 
 UDR0 = c;
 #else
 Serial.write(c);
 #endif
 length--;
 if (! length) {};
 }
 }
 fona.HTTP_POST_end();
 } 
 else 
 {
 Serial.println("Waiting for GPS fix...");
 }
 }